<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://developers.seeka.co
 * @since             1.0.0
 * @package           Seeka_Converge
 *
 * @wordpress-plugin
 * Plugin Name:       Seeka
 * Plugin URI:        https://developers.seeka.co
 * Description:       Automated behaviour detection which resolves and enriches user identity via first-party data methods.
 * Version:           1.0.89
 * Author:            Seeka
 * Author URI:        https://seeka.co
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       seeka-converge
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define('Seeka_CONVERGE_VERSION', '1.0.89');

define('SEEKA_CONVERGE_PLUGIN_DIR', plugin_dir_path(__FILE__));

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-seeka-converge-activator.php
 */
function activate_seeka_converge()
{
	require_once SEEKA_CONVERGE_PLUGIN_DIR . 'includes/class-seeka-converge-activator.php';
	Seeka_Converge_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-seeka-converge-deactivator.php
 */
function deactivate_seeka_converge()
{
	// Load plugin functions if not already available - bedrock compatibility
	if (!function_exists('get_plugins') || !function_exists('is_plugin_active')) {
		require_once ABSPATH . 'wp-admin/includes/plugin.php';
	}

	if (is_plugin_active('seeka-woocommerce/seeka-woocommerce.php')) {
		die('Seeka plugin cannot be deactivated when the Seeka WooCommerce plugin is still active.');
	}

	require_once SEEKA_CONVERGE_PLUGIN_DIR . 'includes/class-seeka-converge-deactivator.php';
	Seeka_Converge_Deactivator::deactivate();
}

register_activation_hook(__FILE__, 'activate_seeka_converge');
register_deactivation_hook(__FILE__, 'deactivate_seeka_converge');

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require SEEKA_CONVERGE_PLUGIN_DIR . 'includes/class-seeka-converge.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_seeka_converge()
{

	$plugin = new Seeka_Converge();
	$plugin->run();
}
run_seeka_converge();
